@@ -24,7 +24,6 @@ this module can be modified.
 from __future__ import division, print_function, absolute_import
 
 import os
-import inspect
 import warnings
 import threading
 from enum import Enum, IntEnum, unique
@@ -39,6 +38,9 @@ from hypothesis.internal.reflection import proxies, \
 from hypothesis.internal.validation import try_convert
 from hypothesis.utils.dynamicvariables import DynamicVariable
 
+if False:
+    from typing import Dict, List  # noqa
+
 __all__ = [
     'settings',
 ]
@@ -47,7 +49,7 @@ __all__ = [
 unlimited = UniqueIdentifier('unlimited')
 
 
-all_settings = {}
+all_settings = {}  # type: Dict[str, Setting]
 
 
 class settingsProperty(object):
@@ -61,7 +63,14 @@ class settingsProperty(object):
             return self
         else:
             try:
-                return obj.__dict__[self.name]
+                result = obj.__dict__[self.name]
+                # This is a gross hack, but it preserves the old behaviour that
+                # you can change the storage directory and it will be reflected
+                # in the default database.
+                if self.name == 'database' and result is not_set:
+                    from hypothesis.database import ExampleDatabase
+                    result = ExampleDatabase(not_set)
+                return result
             except KeyError:
                 raise AttributeError(self.name)
 
@@ -107,7 +116,9 @@ class settingsMeta(type):
         default_variable.value = value
 
 
-class settings(settingsMeta('settings', (object,), {})):
+class settings(
+    settingsMeta('settings', (object,), {})  # type: ignore
+):
     """A settings object controls a variety of parameters that are used in
     falsification. These may control both the falsification strategy and the
     details of the data that is generated.
@@ -120,14 +131,11 @@ class settings(settingsMeta('settings', (object,), {})):
         '_construction_complete', 'storage'
     ]
     __definitions_are_locked = False
-    _profiles = {}
+    _profiles = {}  # type: dict
 
     def __getattr__(self, name):
         if name in all_settings:
-            d = all_settings[name].default
-            if inspect.isfunction(d):
-                d = d()
-            return d
+            return all_settings[name].default
         else:
             raise AttributeError('settings has no attribute %s' % (name,))
 
@@ -495,11 +503,11 @@ warnings.simplefilter('error', HypothesisDeprecationWarning).
 )
 
 
-def _validate_database(db, __from_db_file=False):
+def _validate_database(db, _from_db_file=False):
     from hypothesis.database import ExampleDatabase
     if db is None or isinstance(db, ExampleDatabase):
         return db
-    if __from_db_file or db is not_set:
+    if _from_db_file or db is not_set:
         return ExampleDatabase(db)
     raise InvalidArgument(
         'Arguments to the database setting must be None or an instance of '
@@ -511,7 +519,7 @@ def _validate_database(db, __from_db_file=False):
 
 settings.define_setting(
     'database',
-    default=lambda: _validate_database(not_set),
+    default=not_set,
     show_default=False,
     description="""
 An instance of hypothesis.database.ExampleDatabase that will be
@@ -530,7 +538,7 @@ settings.define_setting(
 The file or directory location to save and load previously tried examples;
 `:memory:` for an in-memory cache or None to disable caching entirely.
 """,
-    validator=lambda f: _validate_database(f, __from_db_file=True),
+    validator=lambda f: _validate_database(f, _from_db_file=True),
     deprecation_message="""
 The `database_file` setting is deprecated in favor of the `database`
 setting, and will be removed in a future version.  It only exists at
@@ -617,16 +625,18 @@ class Verbosity(IntEnum):
     def _get_default():
         var = os.getenv('HYPOTHESIS_VERBOSITY_LEVEL')
         if var is not None:  # pragma: no cover
-            note_deprecation(
+            try:
+                result = Verbosity[var]
+            except KeyError:
+                raise InvalidArgument('No such verbosity level %r' % (var,))
+
+            warnings.warn(HypothesisDeprecationWarning(
                 'The HYPOTHESIS_VERBOSITY_LEVEL environment variable is '
                 'deprecated, and will be ignored by a future version of '
                 'Hypothesis.  Configure your verbosity level via a '
                 'settings profile instead.'
-            )
-            try:
-                return Verbosity[var]
-            except KeyError:
-                raise InvalidArgument('No such verbosity level %r' % (var,))
+            ))
+            return result
         return Verbosity.normal
 
     def __repr__(self):
